==> fdoshp-3.2.3.tar.gz: OpenSource_FDO/Providers/SHP/Src/Provider/ShpFeatureReader.cpp <==
/*
 * 
* Copyright (C) 2004-2006  Autodesk, Inc.
* 
* This library is free software; you can redistribute it and/or
* modify it under the terms of version 2.1 of the GNU Lesser
* General Public License as published by the Free Software Foundation.
* 
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
* 
 */

#include "stdafx.h"

#include <malloc.h>
#include <string.h>

ShpFeatureReader::ShpFeatureReader ()
{
}

ShpFeatureReader::ShpFeatureReader (ShpConnection *connection, FdoString* className, FdoFilter* filter, FdoIdentifierCollection* selected) :
    ShpReader<FdoIFeatureReader> (connection, className, filter, selected)
{
}

ShpFeatureReader::~ShpFeatureReader (void)
{
}

/** Do not implement the copy constructor. **/
//ShpFeatureReader::ShpFeatureReader (const ShpFeatureReader &right) { }

void ShpFeatureReader::Dispose ()
{
    delete this;
}

/// <summary>Gets the definition of the object currently being read. If the user
/// has requested only a subset of the class properties, the class 
/// definition reflects what the user has asked, rather than the full class 
/// definition.</summary>
/// <returns>Returns the class definition object.</returns> 
FdoClassDefinition* ShpFeatureReader::GetClassDefinition ()
{
    FdoPtr<FdoClassDefinition> definition = ShpSchemaUtilities::GetLogicalClassDefinition (mConnection, mClassName, mSelected);
    return (FDO_SAFE_ADDREF (definition.p));
}

/// <summary>Gets a value indicating the depth of nesting for the current reader.
/// The depth value increases each time GetFeatureObject is called and a new 
/// reader is returned. The outermost reader has a depth of 0.</summary>
/// <returns>Returns the depth</returns> 
FdoInt32 ShpFeatureReader::GetDepth ()
{
    return (0);
}

/// <summary>Gets a reference to an FdoIFeatureReader to read the data contained in
/// the object or object collection property. If the property is not an
/// object property, an exception is thrown.</summary>
/// <param name="propertyName">Input the property name.</param> 
/// <returns>Returns the nested feature reader</returns> 
FdoIFeatureReader* ShpFeatureReader::GetFeatureObject (FdoString* propertyName)
{
    throw FdoCommandException::Create(NlsMsgGet(SHP_OBJECT_PROPERTIES_NOT_SUPPORTED, "Object properties are not supported."));
}

==> fdoshp-3.5.0.tar.gz: OpenSource_FDO/Providers/SHP/Src/Provider/ShpFeatureReader.cpp <==
/*
 * 
* Copyright (C) 2004-2006  Autodesk, Inc.
* 
* This library is free software; you can redistribute it and/or
* modify it under the terms of version 2.1 of the GNU Lesser
* General Public License as published by the Free Software Foundation.
* 
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
* 
 */

#include "stdafx.h"

#include <malloc.h>
#include <string.h>

ShpFeatureReader::ShpFeatureReader ()
{
}

ShpFeatureReader::ShpFeatureReader (ShpConnection *connection, FdoString* className, FdoFilter* filter, FdoIdentifierCollection* selected) :
    superclass (connection, className, filter, selected)
{
}

ShpFeatureReader::~ShpFeatureReader (void)
{
}

/** Do not implement the copy constructor. **/
//ShpFeatureReader::ShpFeatureReader (const ShpFeatureReader &right) { }

void ShpFeatureReader::Dispose ()
{
    delete this;
}

/// <summary>Gets the definition of the object currently being read. If the user
/// has requested only a subset of the class properties, the class 
/// definition reflects what the user has asked, rather than the full class 
/// definition.</summary>
/// <returns>Returns the class definition object.</returns> 
FdoClassDefinition* ShpFeatureReader::GetClassDefinition ()
{
    FdoPtr<FdoClassDefinition> definition = ShpSchemaUtilities::GetLogicalClassDefinition (mConnection, mClassName, mSelected);
    return (FDO_SAFE_ADDREF (definition.p));
}

/// <summary>Gets a value indicating the depth of nesting for the current reader.
/// The depth value increases each time GetFeatureObject is called and a new 
/// reader is returned. The outermost reader has a depth of 0.</summary>
/// <returns>Returns the depth</returns> 
FdoInt32 ShpFeatureReader::GetDepth ()
{
    return (0);
}

/// <summary>Gets a reference to an FdoIFeatureReader to read the data contained in
/// the object or object collection property. If the property is not an
/// object property, an exception is thrown.</summary>
/// <param name="propertyName">Input the property name.</param> 
/// <returns>Returns the nested feature reader</returns> 
FdoIFeatureReader* ShpFeatureReader::GetFeatureObject (FdoString* propertyName)
{
    throw FdoCommandException::Create(NlsMsgGet(SHP_OBJECT_PROPERTIES_NOT_SUPPORTED, "Object properties are not supported."));
}
